@@ -6,7 +6,7 @@ type PagerModeMark struct {
 	pager *Pager
 }
 
-func (m PagerModeMark) drawFooter(_ string, _ string) {
+func (m PagerModeMark) drawFooter(_ string, _ string, _ string) {
 	p := m.pager
 
 	_, height := p.screen.Size()
@@ -36,6 +36,6 @@ func (m PagerModeMark) onKey(key twin.KeyCode) {
 }
 
 func (m PagerModeMark) onRune(char rune) {
-	m.pager.marks[char] = m.pager.scrollPosition
+	m.pager.bookmarks[char] = m.pager.scrollPosition
 	m.pager.mode = PagerModeViewing(m)
 }
